]> git.immae.eu Git - github/Chocobozzz/PeerTube.git/blobdiff - server.js
Client: add views information and sort
[github/Chocobozzz/PeerTube.git] / server.js
index d540c301b5213f87d4d80c0195e52acef86b1390..33d399786da00edd0f787ee8cba3b7819ed09ba9 100644 (file)
--- a/server.js
+++ b/server.js
@@ -2,7 +2,6 @@
 
 // ----------- Node modules -----------
 const bodyParser = require('body-parser')
-const cors = require('cors')
 const express = require('express')
 const expressValidator = require('express-validator')
 const http = require('http')
@@ -11,35 +10,37 @@ const path = require('path')
 const TrackerServer = require('bittorrent-tracker').Server
 const WebSocketServer = require('ws').Server
 
+process.title = 'peertube'
+
 // Create our main app
 const app = express()
 
 // ----------- Database -----------
-const config = require('config')
 const constants = require('./server/initializers/constants')
-const database = require('./server/initializers/database')
 const logger = require('./server/helpers/logger')
-
-database.connect()
+// Initialize database and models
+const db = require('./server/initializers/database')
+db.init(onDatabaseInitDone)
 
 // ----------- Checker -----------
 const checker = require('./server/initializers/checker')
 
-const miss = checker.checkConfig()
-if (miss.length !== 0) {
-  throw new Error('Miss some configurations keys : ' + miss)
+const missed = checker.checkMissedConfig()
+if (missed.length !== 0) {
+  throw new Error('Miss some configurations keys : ' + missed)
+}
+
+const errorMessage = checker.checkConfig()
+if (errorMessage !== null) {
+  throw new Error(errorMessage)
 }
 
 // ----------- PeerTube modules -----------
 const customValidators = require('./server/helpers/custom-validators')
+const friends = require('./server/lib/friends')
 const installer = require('./server/initializers/installer')
 const migrator = require('./server/initializers/migrator')
-const mongoose = require('mongoose')
 const routes = require('./server/controllers')
-const Request = mongoose.model('Request')
-
-// Get configurations
-const port = config.get('listen.port')
 
 // ----------- Command line -----------
 
@@ -57,37 +58,26 @@ app.use(expressValidator({
     customValidators.misc,
     customValidators.pods,
     customValidators.users,
-    customValidators.videos
+    customValidators.videos,
+    customValidators.remote.videos
   )
 }))
 
 // ----------- Views, routes and static files -----------
 
-// API routes
+// API
 const apiRoute = '/api/' + constants.API_VERSION
 app.use(apiRoute, routes.api)
 
-// Static files
-app.use('/client', express.static(path.join(__dirname, '/client/dist'), { maxAge: constants.STATIC_MAX_AGE }))
-// 404 for static files not found
-app.use('/client/*', function (req, res, next) {
-  res.sendStatus(404)
-})
-
-const torrentsPhysicalPath = path.join(__dirname, config.get('storage.torrents'))
-app.use(constants.STATIC_PATHS.TORRENTS, cors(), express.static(torrentsPhysicalPath, { maxAge: constants.STATIC_MAX_AGE }))
-
-// Videos path for webseeding
-const videosPhysicalPath = path.join(__dirname, config.get('storage.videos'))
-app.use(constants.STATIC_PATHS.WEBSEED, cors(), express.static(videosPhysicalPath, { maxAge: constants.STATIC_MAX_AGE }))
+// Client files
+app.use('/', routes.client)
 
-// Thumbnails path for express
-const thumbnailsPhysicalPath = path.join(__dirname, config.get('storage.thumbnails'))
-app.use(constants.STATIC_PATHS.THUMBNAILS, express.static(thumbnailsPhysicalPath, { maxAge: constants.STATIC_MAX_AGE }))
+// Static files
+app.use('/', routes.static)
 
-// Client application
+// Always serve index client page (the client is a single page application, let it handle routing)
 app.use('/*', function (req, res, next) {
-  res.sendFile(path.join(__dirname, 'client/dist/index.html'))
+  res.sendFile(path.join(__dirname, './client/dist/index.html'))
 })
 
 // ----------- Tracker -----------
@@ -127,23 +117,29 @@ app.use(function (err, req, res, next) {
   res.sendStatus(err.status || 500)
 })
 
-installer.installApplication(function (err) {
-  if (err) throw err
+// ----------- Run -----------
 
-  // Run the migration scripts if needed
+function onDatabaseInitDone () {
+  const port = constants.CONFIG.LISTEN.PORT
+    // Run the migration scripts if needed
   migrator.migrate(function (err) {
     if (err) throw err
 
-    // ----------- Make the server listening -----------
-    server.listen(port, function () {
-      // Activate the pool requests
-      Request.activate()
+    installer.installApplication(function (err) {
+      if (err) throw err
+
+      // ----------- Make the server listening -----------
+      server.listen(port, function () {
+        // Activate the communication with friends
+        friends.activate()
 
-      logger.info('Seeded all the videos')
-      logger.info('Server listening on port %d', port)
-      app.emit('ready')
+        logger.info('Server listening on port %d', port)
+        logger.info('Webserver: %s', constants.CONFIG.WEBSERVER.URL)
+
+        app.emit('ready')
+      })
     })
   })
-})
+}
 
 module.exports = app